@@ -18,8 +18,8 @@ package Dist::Zilla::Plugin::ArchiveRelease;
 #---------------------------------------------------------------------
 
 use 5.008;
-our $VERSION = '0.04';
-# This file is part of Dist-Zilla-PluginBundle-CJM 0.04 (March 29, 2010)
+our $VERSION = '0.05';
+# This file is part of Dist-Zilla-PluginBundle-CJM 0.05 (March 30, 2010)
 
 
 use Moose;
@@ -98,9 +98,16 @@ Dist::Zilla::Plugin::ArchiveRelease - Move the release tarball to an archive dir
 
 =head1 VERSION
 
-This document describes version 0.04 of
-Dist::Zilla::Plugin::ArchiveRelease, released March 29, 2010
-as part of Dist-Zilla-PluginBundle-CJM version 0.04.
+This document describes version 0.05 of
+Dist::Zilla::Plugin::ArchiveRelease, released March 30, 2010
+as part of Dist-Zilla-PluginBundle-CJM version 0.05.
+
+=head1 SYNOPSIS
+
+In your F<dist.ini>:
+
+  [ArchiveRelease]
+  directory = releases      ; this is the default
 
 =head1 DESCRIPTION
 
