@@ -17,8 +17,8 @@ package Dist::Zilla::Plugin::VersionFromModule;
 # ABSTRACT: Get distribution version from its main_module
 #---------------------------------------------------------------------
 
-our $VERSION = '0.02';
-# This file is part of Dist-Zilla-PluginBundle-CJM 0.04 (March 29, 2010)
+our $VERSION = '0.05';
+# This file is part of Dist-Zilla-PluginBundle-CJM 0.05 (March 30, 2010)
 
 use Moose;
 with 'Dist::Zilla::Role::VersionProvider';
@@ -56,9 +56,15 @@ Dist::Zilla::Plugin::VersionFromModule - Get distribution version from its main_
 
 =head1 VERSION
 
-This document describes version 0.02 of
-Dist::Zilla::Plugin::VersionFromModule, released March 29, 2010
-as part of Dist-Zilla-PluginBundle-CJM version 0.04.
+This document describes version 0.05 of
+Dist::Zilla::Plugin::VersionFromModule, released March 30, 2010
+as part of Dist-Zilla-PluginBundle-CJM version 0.05.
+
+=head1 SYNOPSIS
+
+In your F<dist.ini>:
+
+  [VersionFromModule]
 
 =head1 DESCRIPTION
 
